@@ -117,17 +117,11 @@ struct Dictionary_s
 	const char *    name;
 	const char *    lang;
 
-	int             use_unknown_word;
-	int             unknown_word_defined;
-
-	/* If not null, then use spelling guesser for unknown words */
-	void *          spell_checker; /* spell checker handle */
-#if USE_CORPUS
-	Corpus *        corpus; /* Statistics database */
-#endif
-
-	int             left_wall_defined;
-	int             right_wall_defined;
+	Boolean         use_unknown_word;
+	Boolean         unknown_word_defined;
+	Boolean         left_wall_defined;
+	Boolean         right_wall_defined;
+	Boolean         have_empty_suffix;
 
 	/* Affixes are used during the tokenization stage. */
 	Dictionary      affix_table;
@@ -142,9 +136,14 @@ struct Dictionary_s
 	const char ** prefix;
 	const char ** suffix;
 
+	/* If not null, then use spelling guesser for unknown words */
+	void *          spell_checker; /* spell checker handle */
+#if USE_CORPUS
+	Corpus *        corpus; /* Statistics database */
+#endif
+
 	Postprocessor * postprocessor;
 	Postprocessor * constituent_pp;
-	int             andable_defined;
 	Connector_set * andable_connector_set;  /* NULL=everything is andable */
 	Connector_set * unlimited_connector_set; /* NULL=everthing is unlimited */
 	int             max_cost;
@@ -163,10 +162,10 @@ struct Dictionary_s
 	const wchar_t * input;
 	const wchar_t * pin;
 	char            token[MAX_TOKEN_LENGTH];
-	int             is_special;        /* boolean */
+	Boolean         recursive_error;
+	Boolean         is_special;
 	wint_t          already_got_it;
 	int             line_number;
-	int             recursive_error;   /* boolean */
 	mbstate_t       mbss; /* multi-byte shift state */
 };
 
@@ -218,14 +217,10 @@ struct Sentence_s
 	Dictionary  dict;           /* words are defined from this dictionary */
 	const char *orig_sentence;  /* Copy of original sentence */
 	int    length;              /* number of words */
-	Word   word[MAX_SENTENCE];  /* array of words after tokenization */
-#ifdef USE_FAT_LINKAGES
-	char * is_conjunction;      /* Array of flags, one per word; set to
-	                               TRUE if conjunction, as defined by dictionary */
-	char** deletable;           /* deletable regions in a sentence with conjunction */
-	char** dptr;                /* private pointer for mem management only */
-	char** effective_dist;
-#endif /* USE_FAT_LINKAGES */
+	Word  *word;                /* array of words after tokenization */
+	String_set *   string_set;  /* used for word names, not connectors */
+
+	/* Parse results */
 	int    num_linkages_found;  /* total number before postprocessing.  This
 	                               is returned by the count() function */
 	int    num_linkages_alloced;/* total number of linkages allocated.
@@ -242,16 +237,29 @@ struct Sentence_s
 	int    null_count;          /* number of null links in linkages */
 	Parse_info     parse_info;  /* set of parses for the sentence */
 	Linkage_info * link_info;   /* array of valid and invalid linkages (sorted) */
-	String_set *   string_set;  /* used for word names, not connectors */
-#ifdef USE_FAT_LINKAGES
-	And_data       and_data;    /* used to keep track of fat disjuncts */
-#endif /* USE_FAT_LINKAGES */
-	char  q_pruned_rules;       /* don't prune rules more than once in p.p. */
-	int   post_quote[MAX_SENTENCE]; /* Used only by tokenizer. */
 
+	/* Tokenizer internal/private state */
+	Boolean       *post_quote;
+	Tokenizer     tokenizer;
+
+	/* parser internal/private state */
 	analyze_context_t * analyze_ctxt; /* private state  used for analyzing */
 	count_context_t * count_ctxt; /* private state info used for counting */
 	match_context_t * match_ctxt; /* private state info used for matching */
+
+#ifdef USE_FAT_LINKAGES
+	/* Obsolete fat-linkage state */
+	char * is_conjunction;      /* Array of flags, one per word; set to
+	                               TRUE if conjunction, as defined by dictionary */
+	char** deletable;           /* deletable regions in a sentence with conjunction */
+	char** dptr;                /* private pointer for mem management only */
+	char** effective_dist;
+	And_data       and_data;    /* used to keep track of fat disjuncts */
+#endif /* USE_FAT_LINKAGES */
+
+	/* Post-processor priavte/internal state */
+	Boolean  q_pruned_rules;    /* don't prune rules more than once in p.p. */
+
 	/* thread-safe random number state */
 	unsigned int rand_state;
 
