@@ -17,6 +17,7 @@
 #include "error.h"
 #include "constituents.h"
 #include "post-process.h"
+#include "print-util.h"
 
 #define MAXCONSTITUENTS 8192
 #define MAXSUBL 16
@@ -938,7 +939,7 @@ static int last_minute_fixes(con_context_t *ctxt, Linkage linkage, int numcon_to
 		if ((ctxt->constituent[c].right == linkage->num_words -3) &&
 			(ctxt->constituent[c].left == 1) &&
 			(strcmp(ctxt->constituent[c].type, "S") == 0) &&
-			(strcmp(sent->word[linkage->num_words -2].string, ".") == 0))
+			(strcmp(sent->word[linkage->num_words -2].alternatives[0], ".") == 0))
 			ctxt->constituent[c].right++;
 	}
 
@@ -1506,7 +1507,10 @@ static char * exprint_constituent_structure(con_context_t *ctxt, Linkage linkage
 		if (have_opened && (w < linkage->num_words - 1))
 		{
 			char *p;
-			strcpy(s, sent->word[w].string);
+			/* XXX FIXME -- using alternatives[0] is wrong here,
+			 * especially for Russian. We'll punt for now, though.
+			 * Consider using linkage->word[w] instead. */
+			strcpy(s, sent->word[w].alternatives[0]);
 
 			/* Constituent processing will crash if the sentence contains
 			 * square brackets, so we have to do something ... replace
@@ -1528,7 +1532,7 @@ static char * exprint_constituent_structure(con_context_t *ctxt, Linkage linkage
 
 			/* Now, if the first character of the word was
 			   originally uppercase, we put it back that way */
-			if (sent->word[w].firstupper == 1)
+			if (sent->word[w].firstupper)
 				upcase_utf8_str(s, s, MAX_WORD);
 			append_string(cs, "%s ", s);
 		}
