@@ -17,13 +17,16 @@ LINK_BEGIN_DECLS
 
 #include "api-types.h"
 
-int  read_dictionary(Dictionary dict);
-void dict_display_word_info(Dictionary dict, const char * s);
-void dict_display_word_expr(Dictionary dict, const char * s);
+Boolean read_dictionary(Dictionary dict);
+void dict_display_word_info(Dictionary dict, const char *);
+void dict_display_word_expr(Dictionary dict, const char *);
 void print_dictionary_data(Dictionary dict);
 void print_dictionary_words(Dictionary dict);
 void print_expression(Exp *);
-int  boolean_dictionary_lookup(Dictionary dict, const char *);
+
+Boolean boolean_dictionary_lookup(Dictionary dict, const char *);
+Boolean find_word_in_dict(Dictionary dict, const char *);
+
 int  delete_dictionary_words(Dictionary dict, const char *);
 
 Dict_node * dictionary_lookup_list(Dictionary dict, const char *);
@@ -36,4 +39,10 @@ Exp *       Exp_create(Dictionary dict);
 
 Dictionary dictionary_create_from_utf8(const char * input);
 
+Dictionary
+dictionary_six(const char * lang, const char * dict_name,
+                const char * pp_name, const char * cons_name,
+                const char * affix_name, const char * regex_name);
+
+
 LINK_END_DECLS
