@@ -19,7 +19,10 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+
+#ifndef _WIN32
 #include <unistd.h>
+#endif /* _WIN32 */
 
 
 #ifdef USE_PTHREADS
@@ -161,11 +164,12 @@ strtok_r (char *s, const char *delim, char **saveptr)
 char *
 strndup (char *str, size_t size)
 {
+	size_t len;
 	char *result = (char *) NULL;
 
 	if ((char *) NULL == str) return (char *) NULL;
 
-	size_t len = strlen (str);
+	len = strlen (str);
 	if (!len) return strdup ("");
 	if (size > len) size = len;
 
@@ -180,6 +184,16 @@ strndup (char *str, size_t size)
 /* ============================================================= */
 /* UTF8 utilities */
 
+int wctomb_check(char *s, wchar_t wc, mbstate_t *ps)
+{
+	int nr = wcrtomb(s, wc, ps);
+	if (nr < 0) {
+		prt_error("Fatal Error: unknown character set %s\n", nl_langinfo(CODESET));
+		exit(1);
+	}
+	return nr;
+}
+
 /**
  * Downcase the first letter of the word.
  */
@@ -199,7 +213,7 @@ void downcase_utf8_str(char *to, const char * from, size_t usize)
 	if ((nbh < nbl) && (to == from))
 	{
 		/* I'm to lazy to fix this */
-		prt_error("Error: can't downcase multi-byte string!\n");
+		prt_error("Error: can't downcase multi-byte string!");
 		return;
 	}
 
@@ -232,7 +246,7 @@ void upcase_utf8_str(char *to, const char * from, size_t usize)
 	if ((nbh < nbl) && (to == from))
 	{
 		/* I'm to lazy to fix this */
-		prt_error("Error: can't upcase multi-byte string!\n");
+		prt_error("Error: can't upcase multi-byte string!");
 		return;
 	}
 
@@ -368,7 +382,7 @@ void * xalloc(size_t size)
 #endif /* TRACK_SPACE_USAGE */
 	if ((p == NULL) && (size != 0))
 	{
-		prt_error("Fatal Error: Ran out of space.\n");
+		prt_error("Fatal Error: Ran out of space.");
 		abort();
 		exit(1);
 	}
@@ -384,7 +398,7 @@ void * xrealloc(void *p, size_t oldsize, size_t newsize)
 	p = realloc(p, newsize);
 	if ((p == NULL) && (newsize != 0))
 	{
-		prt_error("Fatal Error: Ran out of space on realloc.\n");
+		prt_error("Fatal Error: Ran out of space on realloc.");
 		abort();
 		exit(1);
 	}
@@ -415,7 +429,7 @@ void * exalloc(size_t size)
 
 	if ((p == NULL) && (size != 0))
 	{
-		prt_error("Fatal Error: Ran out of space.\n");
+		prt_error("Fatal Error: Ran out of space.");
 		abort();
 		exit(1);
 	}
@@ -577,7 +591,7 @@ char * dictionary_get_data_dir(void)
 		if (GetModuleFileName(hInstance, dll_path, MAX_PATH))
 		{
 #ifdef _DEBUG
-			prt_error("Info: GetModuleFileName=%s\n", (dll_path ? dll_path : "NULL"));
+			prt_error("Info: GetModuleFileName=%s", (dll_path ? dll_path : "NULL"));
 #endif
 			data_dir = path_get_dirname(dll_path);
 		}
@@ -609,7 +623,7 @@ char * dictionary_get_data_dir(void)
 					prog_path[i] = prog_path16[k];
 				}
 #ifdef _DEBUG
-				prt_error("Info: GetModuleFileName=%s\n", (prog_path ? prog_path : "NULL"));
+				prt_error("Info: GetModuleFileName=%s", (prog_path ? prog_path : "NULL"));
 #endif
 				data_dir16 = path_get_dirname(prog_path);
 				if (data_dir16 != NULL)
@@ -680,7 +694,7 @@ void * object_open(const char *filename,
 	{
 		char * data_dir = dictionary_get_data_dir();
 #ifdef _DEBUG
-		prt_error("Info: data_dir=%s\n", (data_dir?data_dir:"NULL"));
+		prt_error("Info: data_dir=%s", (data_dir?data_dir:"NULL"));
 #endif
 		if (data_dir) {
 			snprintf(fulldictpath, MAX_PATH_NAME,
@@ -717,7 +731,7 @@ void * object_open(const char *filename,
 		*(completename+(pos-oldpos)) = DIR_SEPARATOR;
 		strcpy(completename+(pos-oldpos)+1, filename);
 #ifdef _DEBUG
-		prt_error("Info: object_open() trying %s\n", completename);
+		prt_error("Info: object_open() trying %s", completename);
 #endif
 		if ((fp = opencb(completename, user_data)) != NULL) {
 			return fp;
@@ -737,7 +751,7 @@ static void * dict_file_open(const char * fullname, void * user_data)
 	if (fh && NULL == path_found)
 	{
 		path_found = strdup (fullname);
-		prt_error("Info: Dictionary found at %s\n", fullname);
+		prt_error("Info: Dictionary found at %s", fullname);
 	}
 	return (void *) fh;
 }
@@ -779,8 +793,9 @@ FILE *dictopen(const char *filename, const char *how)
 /**
  * Read in the whole stinkin file.
  * We read it as wide chars, one char at a time, so that any LC_CTYPE
- * setting are obeyed.  Later, during dictionary grokking, thesse will
- * be converted to the internal UTF8 format.
+ * setting are obeyed.  Later, during dictionary grokking, these will
+ * be converted to the internal UTF8 format.  This routine returns
+ * malloced memory, which should be freed as soon as possible.
  */
 wchar_t *get_file_contents(const char * dict_name)
 {
@@ -800,12 +815,14 @@ wchar_t *get_file_contents(const char * dict_name)
 	tot_size = buf.st_size;
 
 	/* This is surely more than we need. But that's OK, better
-	 * too much than too little.  */
-	contents = (wchar_t *) malloc(sizeof(wchar_t) * (tot_size+1));
+	 * too much than too little.  That is, the file-size (measured
+	 * in bytes) over-estimate for the number of wide chars that
+	 * we expect to get out of it. 7 more for good luck. (wide chars)*/
+	contents = (wchar_t *) malloc(sizeof(wchar_t) * (tot_size+7));
 
 	/* Now, read the whole file. */
 	p = contents;
-	left = tot_size + 1;
+	left = tot_size + 7;
 	while (1)
 	{
 		wchar_t *rv = fgetws(p, left, fp);
@@ -820,7 +837,7 @@ wchar_t *get_file_contents(const char * dict_name)
 
 	if (left < 0)
 	{
-		prt_error("Fatal Error: File size is insane!\n");
+		prt_error("Fatal Error: File size is insane!");
 		exit(1);
 	}
 
