@@ -146,14 +146,32 @@ int strncasecmp(const char *s1, const char *s2, size_t n);
 #define GNUC_MALLOC
 #endif
 
-static inline int wctomb_check(char *s, wchar_t wc, mbstate_t *ps)
+/**
+ * Return the length, in codepoints/glyphs, of the utf8-encoded 
+ * string.  This is needed when printing strings in a formatted way.
+ */
+static inline size_t utf8_strlen(const char *s)
 {
-	int nr = wcrtomb(s, wc, ps);
-	if (nr < 0) {
-		prt_error("Fatal Error: unknown character set %s\n", nl_langinfo(CODESET));
-		exit(1);
+	mbstate_t mbss;
+	memset(&mbss, 0, sizeof(mbss));
+
+	return mbsrtowcs(NULL, &s, 0, &mbss);
+}
+
+/**
+ * Return the distance, in bytes, to the next character, in this
+ * input utf8-encoded string
+ */
+static inline size_t utf8_next(const char *s)
+{
+	int n = 0;
+	while (0 != *s)
+	{
+		if ((0x80 <= ((unsigned char) *s)) && 
+        (((unsigned char) *s) < 0xc0)) { s++; n++; }
+		else return n+1;
 	}
-	return nr;
+	return n;
 }
 
 static inline int is_utf8_upper(const char *s)
@@ -242,6 +260,7 @@ static inline int utf8_upper_match(const char * s, const char * t)
 	return TRUE;
 }
 
+int wctomb_check(char *s, wchar_t wc, mbstate_t *ps);
 void downcase_utf8_str(char *to, const char * from, size_t usize);
 void upcase_utf8_str(char *to, const char * from, size_t usize);
 
