@@ -1,8 +1,12 @@
 /*************************************************************************/
-/* Copyright (c) 2012                                                    */
-/* Linas Vepstas <linasvepstas@gmail.com>                                */
+/* Copyright (c) 2012 Linas Vepstas <linasvepstas@gmail.com>             */
 /* All rights reserved                                                   */
 /*                                                                       */
+/* Use of the Viterbi parsing system is subject to the terms of the      */
+/* license set forth in the LICENSE file included with this software.    */
+/* This license allows free redistribution and use in source and binary  */
+/* forms, with or without modification, subject to certain conditions.   */
+/*                                                                       */
 /*************************************************************************/
 
 #ifndef _LG_VITERBI_ATOM_H
@@ -39,7 +43,6 @@ enum AtomType
 	SEQ,        // ordered sequence of children
 	AND,        // ordered AND of all children (order is important!)
 	OR,         // unordered OR of all children
-	// OPTIONAL,   // one child only, and its optional. XXX not used ATM
 	WORD_CSET,  // word, followed by a set of connectors for that word.
 	WORD_DISJ,  // word, followed by a single disjunct for that word.
 	LING,       // two connected connectors, (LGLINK) e.g. Dmcn w/o direction info
@@ -50,7 +53,7 @@ enum AtomType
 
 /* Base class for Nodes and Links */
 /* Atoms are not mutable, except for the TV value. That is, you cannot
- * change the type of the atom.
+ * change the type of the atom.  In particular, all methods are const.
  */
 class Atom
 {
@@ -61,7 +64,7 @@ class Atom
 		virtual bool operator==(const Atom*) const;
 		virtual ~Atom() {}
 	protected:
-		AtomType _type;
+		const AtomType _type;
 };
 
 /* A Node may be 
@@ -70,6 +73,7 @@ class Atom
  -- a disjunct (the std::string holds the disjunct)
  -- etc.
  * Nodes are immuatble; the name can be set but not changed.
+ * Note: all methods are const.
  */
 class Node : public Atom
 {
@@ -81,7 +85,7 @@ class Node : public Atom
 
 		virtual bool operator==(const Atom*) const;
 	protected:
-		std::string _name;
+		const std::string _name;
 };
 
 // Uhhhh ... 
@@ -90,6 +94,7 @@ typedef std::vector<Atom*> OutList;
 /*
  * Links hold a bunch of atoms
  * Links are immutable; the outgoing set cannot be changed.
+ * Note: all methods are const.
  */
 class Link : public Atom
 {
@@ -101,31 +106,23 @@ class Link : public Atom
 			: Atom(t)
 		{}
 		Link(AtomType t, Atom* a)
-			: Atom(t)
-		{
-			_oset.push_back(a);
-		}
+			: Atom(t), _oset(1, a)
+		{}
 		Link(AtomType t, Atom* a, Atom*b)
-			: Atom(t)
-		{
-			_oset.push_back(a);
-			_oset.push_back(b);
-		}
-		Link(AtomType t, Atom* a, Atom*b, Atom* c)
-			: Atom(t)
-		{
-			_oset.push_back(a);
-			_oset.push_back(b);
-			_oset.push_back(c);
-		}
+			: Atom(t), _oset(({OutList o(1,a); o.push_back(b); o;}))
+		{}
+		Link(AtomType t, Atom* a, Atom* b, Atom* c)
+			: Atom(t), _oset(({OutList o(1,a); o.push_back(b);
+			                   o.push_back(c); o;}))
+		{}
 		size_t get_arity() const { return _oset.size(); }
 		Atom* get_outgoing_atom(size_t pos) const { return _oset.at(pos); }
 		const OutList& get_outgoing_set() const { return _oset; }
 
 		virtual bool operator==(const Atom*) const;
 	protected:
-		// Outgoing set
-		OutList _oset;
+		// Outgoing set is const, nnot modifiable.
+		const OutList _oset;
 };
 
 std::ostream& operator<<(std::ostream& out, const Atom*);
